gifmaker
========

.. image:: https://raw.githubusercontent.com/neuropoly/gifmaker/master/docs/brain.gif

Convert a series of images into a gif animation, with the possibility to apply
various processing on the input image (cropping, rescaling, etc.).

For installation and usage, please see the `Documentation <https://neuropoly.github.io/gifmaker>`_.
